#!/usr/bin/env python
# 
# ___INFO__MARK_BEGIN__
########################################################################## 
# Copyright 2016,2017 Univa Corporation
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0 
# 
# Unless required by applicable law or agreed to in writing, software 
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
# See the License for the specific language governing permissions and 
# limitations under the License. 
########################################################################### 
# ___INFO__MARK_END__
# 
import re
from uge.exceptions.object_not_found import ObjectNotFound
from uge.exceptions.invalid_argument import InvalidArgument
from uge.exceptions.invalid_request import InvalidRequest
from uge.objects.qconf_object_factory import QconfObjectFactory
from .dict_based_object_manager import DictBasedObjectManager


class HostGroupManager(DictBasedObjectManager):
    QCONF_ERROR_REGEX_LIST = [
        (re.compile('host group name.*is not valid'), InvalidArgument),
        (re.compile('.*following cluster queues still reference.*'), InvalidRequest),
        (re.compile('.*unable to resolve host.*'), ObjectNotFound),
        (re.compile('.*no host group list defined.*'), ObjectNotFound),
    ]

    # Failure incorrectly classified as successful outcome
    QCONF_FAILURE_REGEX_LIST = []

    GENERATE_OBJECT_FACTORY_METHOD = QconfObjectFactory.generate_host_group
    OBJECT_NAME_KEY = 'group_name'
    OBJECT_CLASS_NAME = 'HostGroup'
    OBJECT_CLASS_UGE_NAME = 'hgrp'

    def __init__(self, qconf_executor):
        DictBasedObjectManager.__init__(self, qconf_executor)


#############################################################################
# Testing.
if __name__ == '__main__':
    pass



from uge.exceptions.authorization_error import AuthorizationError
from uge.exceptions.command_failed import CommandFailed
from uge.exceptions.configuration_error import ConfigurationError
from uge.exceptions.invalid_argument import InvalidArgument
from uge.exceptions.invalid_request import InvalidRequest
from uge.exceptions.object_already_exists import ObjectAlreadyExists
from uge.exceptions.object_not_found import ObjectNotFound
from uge.exceptions.qconf_exception import QconfException
from uge.exceptions.qmaster_unreachable import QmasterUnreachable
from uge.exceptions.ar_exception import AdvanceReservationException



#!/usr/bin/env python
# 
# ___INFO__MARK_BEGIN__
########################################################################## 
# Copyright 2016,2017 Univa Corporation
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0 
# 
# Unless required by applicable law or agreed to in writing, software 
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
# See the License for the specific language governing permissions and 
# limitations under the License. 
########################################################################### 
# ___INFO__MARK_END__
# 
import re
from uge.exceptions.object_not_found import ObjectNotFound
from uge.exceptions.invalid_request import InvalidRequest
from uge.exceptions.object_already_exists import ObjectAlreadyExists
from .list_based_object_manager import ListBasedObjectManager


class ManagerManager(ListBasedObjectManager):
    QCONF_ERROR_REGEX_LIST = [
        (re.compile('.*already exists.*'), ObjectAlreadyExists),
        (re.compile('.*does not exist.*'), ObjectNotFound),
        (re.compile('.*may not remove.*'), InvalidRequest),
    ]

    OBJECT_NAME = 'manager'
    OBJECT_CLASS_UGE_NAME = 'm'

    def __init__(self, qconf_executor):
        ListBasedObjectManager.__init__(self, qconf_executor)


#############################################################################
# Testing.
if __name__ == '__main__':
    pass



#!/usr/bin/env python
# 
# ___INFO__MARK_BEGIN__
########################################################################## 
# Copyright 2016,2017 Univa Corporation
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0 
# 
# Unless required by applicable law or agreed to in writing, software 
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
# See the License for the specific language governing permissions and 
# limitations under the License. 
########################################################################### 
# ___INFO__MARK_END__
# 
from .utils import needs_uge
from .utils import generate_random_string
from .utils import create_config_file

from uge.api.qconf_api import QconfApi
from uge.config.config_manager import ConfigManager
from uge.log.log_manager import LogManager
from uge.exceptions.object_not_found import ObjectNotFound
from uge.exceptions.object_already_exists import ObjectAlreadyExists

create_config_file()
API = QconfApi()
CALENDAR_NAME = '%s' % generate_random_string(6)
CONFIG_MANAGER = ConfigManager.get_instance()
LOG_MANAGER = LogManager.get_instance()


@needs_uge
def test_object_not_found():
    try:
        calendar = API.get_cal('__non_existent_calendar__')
        assert (False)
    except ObjectNotFound as ex:
        # ok
        pass


def test_generate_cal():
    calendar = API.generate_cal(CALENDAR_NAME)
    assert (calendar.data['calendar_name'] == CALENDAR_NAME)


def test_add_cal():
    try:
        calendar_list = API.list_cals()
    except ObjectNotFound as ex:
        # no calendars defined
        calendar_list = []
    calendar = API.add_cal(name=CALENDAR_NAME)
    assert (calendar.data['calendar_name'] == CALENDAR_NAME)
    calendar_list2 = API.list_cals()
    assert (len(calendar_list2) == len(calendar_list) + 1)
    assert (calendar_list2.count(CALENDAR_NAME) == 1)


def test_list_cals():
    calendar_list = API.list_cals()
    assert (calendar_list is not None)


def test_object_already_exists():
    try:
        calendar = API.add_cal(name=CALENDAR_NAME)
        assert (False)
    except ObjectAlreadyExists as ex:
        # ok
        pass


def test_get_cal():
    calendar = API.get_cal(CALENDAR_NAME)
    assert (calendar.data['calendar_name'] == CALENDAR_NAME)


def test_generate_cal_from_json():
    cal = API.get_cal(CALENDAR_NAME)
    assert (cal.data['calendar_name'] == CALENDAR_NAME)
    json = cal.to_json()
    cal2 = API.generate_object(json)
    assert (cal2.__class__.__name__ == cal.__class__.__name__)
    for key in list(cal.data.keys()):
        v = cal.data[key]
        v2 = cal2.data[key]
        assert (str(v) == str(v2))


def test_modify_cal():
    calendar = API.get_cal(CALENDAR_NAME)
    week = calendar.data['week']
    calendar = API.modify_cal(name=CALENDAR_NAME, data={'week': '1-2'})
    week2 = calendar.data['week']
    assert (week2 == '1-2')


def test_delete_cal():
    calendar_list = API.list_cals()
    API.delete_cal(CALENDAR_NAME)
    try:
        calendar_list2 = API.list_cals()
    except ObjectNotFound as ex:
        # no calendars defined
        calendar_list2 = []
    assert (len(calendar_list2) == len(calendar_list) - 1)
    assert (calendar_list2.count(CALENDAR_NAME) == 0)



#!/usr/bin/env python
#
# ___INFO__MARK_BEGIN__
##########################################################################
# Copyright 2016,2017 Univa Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
###########################################################################
# ___INFO__MARK_END__
#
from nose import SkipTest

from .utils import needs_uge
from .utils import generate_random_string
from .utils import create_config_file

from uge.api.ar_api import AdvanceReservationApi
from uge.config.config_manager import ConfigManager
from uge.log.log_manager import LogManager
from uge.exceptions.object_not_found import ObjectNotFound
from uge.exceptions.object_already_exists import ObjectAlreadyExists

create_config_file()
AR_API = AdvanceReservationApi()
# AR_NAME = '%s' % generate_random_string(6)
# CONFIG_MANAGER = ConfigManager.get_instance()
LOG_MANAGER = LogManager.get_instance()
logger = LOG_MANAGER.get_logger('test_ar')


@needs_uge
def test_request_ar():
    ar_id = AR_API.request_ar('-d 3600 -fr y')
    ar = AR_API.get_ar(ar_id)
    logger.info('AR: ', ar)
    assert (ar_id is not None)


def test_request_sr():
    ar_id = AR_API.request_ar('-cal_week mon-fri=8-16=on')
    ar = AR_API.get_ar(ar_id)
    logger.info('SR: ', ar)
    assert (ar_id is not None)


def test_get_ar_summary():
    ar_summary = AR_API.get_ar_summary()
    logger.info(ar_summary)
    assert (ar_summary is not None)


def test_get_ar():
    for ar_id in AR_API.get_ar_list():
        ar = AR_API.get_ar(str(ar_id))
        assert (ar is not None)
    else:
        raise SkipTest('There are no UGE advance reservations.')


def test_delete_all_ar():
    for ar_id in AR_API.get_ar_list():
        AR_API.delete_ar(ar_id)



#!/usr/bin/env python
# 
#___INFO__MARK_BEGIN__ 
########################################################################## 
# Copyright 2016,2017 Univa Corporation
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0 
# 
# Unless required by applicable law or agreed to in writing, software 
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
# See the License for the specific language governing permissions and 
# limitations under the License. 
########################################################################### 
#___INFO__MARK_END__ 
# 

UGE_OK = 0
UGE_ERROR = 1
UGE_CONFIGURATION_ERROR = 2
UGE_AUTHORIZATION_ERROR = 3
UGE_COMMAND_FAILED = 4
UGE_INVALID_REQUEST = 5
UGE_INVALID_ARGUMENT = 6
UGE_QMASTER_UNREACHABLE = 7
UGE_OBJECT_NOT_FOUND = 8
UGE_OBJECT_ALREADY_EXISTS = 9

